@@ -1,6 +1,4 @@
-import sys
-
-__version__ = "0.5.0"
+__version__ = "0.5.3"
 __author__ = "np1"
 __license__ = "LGPLv3"
 
@@ -13,8 +11,3 @@ from .pafy import get_categoryname
 from .pafy import backend
 from .util import GdataError, call_gdata
 from .playlist import get_playlist, get_playlist2
-
-if "test" not in sys.argv[0]:
-    del pafy
-
-del sys
